<tr class="noCover"><td class="line"><a name="1">1</a></td><td class="hits"></td><td class="code">&#34;&#34;&#34;Classes and functions that generate CSV files.</td></tr><tr class="noCover"><td class="line"><a name="2">2</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="3">3</a></td><td class="hits"></td><td class="code">This module is focused on generating a CSV file via the CSVReport class, which </td></tr><tr class="noCover"><td class="line"><a name="4">4</a></td><td class="hits"></td><td class="code">is a collections of CSVDataclass objects.</td></tr><tr class="noCover"><td class="line"><a name="5">5</a></td><td class="hits"></td><td class="code">&#34;&#34;&#34;</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="6">6</a></td><td class="hits">1</td><td class="code">import logging</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="7">7</a></td><td class="hits">1</td><td class="code">import operator</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="8">8</a></td><td class="hits">1</td><td class="code">import os</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="9">9</a></td><td class="hits">1</td><td class="code">from typing import Generic, Iterable, List, Tuple, TypeVar</td></tr><tr class="noCover"><td class="line"><a name="10">10</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="11">11</a></td><td class="hits">1</td><td class="code">import pathvalidate</td></tr><tr class="noCover"><td class="line"><a name="12">12</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="13">13</a></td><td class="hits">1</td><td class="code">from . import io</td></tr><tr class="noCover"><td class="line"><a name="14">14</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="15">15</a></td><td class="hits">1</td><td class="code">logger &#61; logging.getLogger(__name__)</td></tr><tr class="noCover"><td class="line"><a name="16">16</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="17">17</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="18">18</a></td><td class="hits">1</td><td class="code">class CSVDataclass:</td></tr><tr class="noCover"><td class="line"><a name="19">19</a></td><td class="hits"></td><td class="code">    &#34;&#34;&#34;Base class that provides a &#34;table_header&#34; class property </td></tr><tr class="noCover"><td class="line"><a name="20">20</a></td><td class="hits"></td><td class="code">    as well as a &#34;as_table_row()&#34; method for simple dataclasses.dataclass.</td></tr><tr class="noCover"><td class="line"><a name="21">21</a></td><td class="hits"></td><td class="code">    &#34;&#34;&#34;</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="22">22</a></td><td class="hits">1</td><td class="code">    &#64;classmethod</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="23">23</a></td><td class="hits">1</td><td class="code">    def table_header(cls) -&gt; Tuple[str, ...]:</td></tr><tr class="noCover"><td class="line"><a name="24">24</a></td><td class="hits"></td><td class="code">        &#34;&#34;&#34;Return the *names* from all attributes of this class.</td></tr><tr class="noCover"><td class="line"><a name="25">25</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="26">26</a></td><td class="hits"></td><td class="code">        Returns:</td></tr><tr class="noCover"><td class="line"><a name="27">27</a></td><td class="hits"></td><td class="code">            Tuple[str,...]: The names of the attributes for this class.</td></tr><tr class="noCover"><td class="line"><a name="28">28</a></td><td class="hits"></td><td class="code">        &#34;&#34;&#34;</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="29">29</a></td><td class="hits">1</td><td class="code">        return tuple(cls.__dataclass_fields__.keys())</td></tr><tr class="noCover"><td class="line"><a name="30">30</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="31">31</a></td><td class="hits">1</td><td class="code">    def as_table_row(self, select_columns: Iterable[str] &#61; None) -&gt; Tuple[str, ...]:</td></tr><tr class="noCover"><td class="line"><a name="32">32</a></td><td class="hits"></td><td class="code">        &#34;&#34;&#34;Return the data from all attributes of this object.</td></tr><tr class="noCover"><td class="line"><a name="33">33</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="34">34</a></td><td class="hits"></td><td class="code">        Args:</td></tr><tr class="noCover"><td class="line"><a name="35">35</a></td><td class="hits"></td><td class="code">            select_columns (Iterable[str], optional): Which data to be returned? If unset, all data returned.</td></tr><tr class="noCover"><td class="line"><a name="36">36</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="37">37</a></td><td class="hits"></td><td class="code">        Returns:</td></tr><tr class="noCover"><td class="line"><a name="38">38</a></td><td class="hits"></td><td class="code">            Tuple[str,...]: The values of all the attributes for this object.</td></tr><tr class="noCover"><td class="line"><a name="39">39</a></td><td class="hits"></td><td class="code">        &#34;&#34;&#34;</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="40">40</a></td><td class="hits">1</td><td class="code">        obj_data &#61; vars(self)</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="41">41</a></td><td class="hits">1</td><td class="code">        if select_columns:</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="42">42</a></td><td class="hits">1</td><td class="code">            row &#61; tuple(obj_data[col] for col in select_columns)</td></tr><tr class="noCover"><td class="line"><a name="43">43</a></td><td class="hits"></td><td class="code">        else:</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="44">44</a></td><td class="hits">1</td><td class="code">            row &#61; tuple(obj_data.values())</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="45">45</a></td><td class="hits">1</td><td class="code">        row_as_strs &#61; tuple(str(datum) for datum in row)</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="46">46</a></td><td class="hits">1</td><td class="code">        return row_as_strs</td></tr><tr class="noCover"><td class="line"><a name="47">47</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="48">48</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="49">49</a></td><td class="hits">1</td><td class="code">CSVDataclass_t &#61; TypeVar(&#39;CSVDataclass_t&#39;, bound&#61;CSVDataclass)</td></tr><tr class="noCover"><td class="line"><a name="50">50</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="51">51</a></td><td class="hits">1</td><td class="code">class CSVReport(Generic[CSVDataclass_t]):</td></tr><tr class="noCover"><td class="line"><a name="52">52</a></td><td class="hits"></td><td class="code">    &#34;&#34;&#34;Base class for reports that can be exported to Comma Separated Values (CSV).</td></tr><tr class="noCover"><td class="line"><a name="53">53</a></td><td class="hits"></td><td class="code">    &#34;&#34;&#34;</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="54">54</a></td><td class="hits">1</td><td class="code">    def __init__(self, items: List[CSVDataclass_t], table_header: Tuple[str,...] &#61; None):</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="55">55</a></td><td class="hits">1</td><td class="code">        self._header: Tuple[str,...] &#61; table_header</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="56">56</a></td><td class="hits">1</td><td class="code">        self._items: List[CSVDataclass_t] &#61; items</td></tr><tr class="noCover"><td class="line"><a name="57">57</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="58">58</a></td><td class="hits">1</td><td class="code">    def sort(self, *sort_by: str):</td></tr><tr class="noCover"><td class="line"><a name="59">59</a></td><td class="hits"></td><td class="code">        &#34;&#34;&#34;Sort this report. (in-place)</td></tr><tr class="noCover"><td class="line"><a name="60">60</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="61">61</a></td><td class="hits"></td><td class="code">        Args:</td></tr><tr class="noCover"><td class="line"><a name="62">62</a></td><td class="hits"></td><td class="code">            sort_by (Union[str,List[str]], optional): The column(s) to be sorted by. By default sort by the first column indicated by table_header.</td></tr><tr class="noCover"><td class="line"><a name="63">63</a></td><td class="hits"></td><td class="code">        &#34;&#34;&#34;</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="64">64</a></td><td class="hits">1</td><td class="code">        if not sort_by:</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="65">65</a></td><td class="hits">1</td><td class="code">            sort_by &#61; self.table_header()</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="66">66</a></td><td class="hits">1</td><td class="code">        self.items.sort(key&#61;operator.attrgetter(*sort_by))</td></tr><tr class="noCover"><td class="line"><a name="67">67</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="68">68</a></td><td class="hits">1</td><td class="code">    &#64;property</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="69">69</a></td><td class="hits">1</td><td class="code">    def items(self) -&gt; List[CSVDataclass_t]:</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="70">70</a></td><td class="hits">1</td><td class="code">        return self._items</td></tr><tr class="noCover"><td class="line"><a name="71">71</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="72">72</a></td><td class="hits">1</td><td class="code">    def table_header(self) -&gt; Tuple[str, ...]:</td></tr><tr class="noCover"><td class="line"><a name="73">73</a></td><td class="hits"></td><td class="code">        &#34;&#34;&#34;Return the CSV header for this Report.</td></tr><tr class="noCover"><td class="line"><a name="74">74</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="75">75</a></td><td class="hits"></td><td class="code">        Returns:</td></tr><tr class="noCover"><td class="line"><a name="76">76</a></td><td class="hits"></td><td class="code">            Tuple[str,...]: Names of columns for this report.</td></tr><tr class="noCover"><td class="line"><a name="77">77</a></td><td class="hits"></td><td class="code">        &#34;&#34;&#34;</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="78">78</a></td><td class="hits">1</td><td class="code">        if self._header: </td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="79">79</a></td><td class="hits">1</td><td class="code">            return self._header</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="80">80</a></td><td class="hits">1</td><td class="code">        try:</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="81">81</a></td><td class="hits">1</td><td class="code">            return self.items[0].table_header()</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="82">82</a></td><td class="hits">1</td><td class="code">        except (IndexError, AttributeError):</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="83">83</a></td><td class="hits">1</td><td class="code">            raise ValueError(f&#39;No header provided. Unable to determine table header for {self.__class__.__name__} with data &#34;{self.items}&#34;.&#39;)</td></tr><tr class="noCover"><td class="line"><a name="84">84</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="85">85</a></td><td class="hits">1</td><td class="code">    def _as_tuples(self) -&gt; List[Tuple]:</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="86">86</a></td><td class="hits">1</td><td class="code">        select_cols &#61; self.table_header()</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="87">87</a></td><td class="hits">1</td><td class="code">        return [item.as_table_row(select_cols) for item in self.items]</td></tr><tr class="noCover"><td class="line"><a name="88">88</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="89">89</a></td><td class="hits">1</td><td class="code">    def as_csv(self, delim&#61;&#39;,&#39;, override_header: Iterable[str] &#61; None) -&gt; str:</td></tr><tr class="noCover"><td class="line"><a name="90">90</a></td><td class="hits"></td><td class="code">        &#34;&#34;&#34;Produce this data structure into a CSV.</td></tr><tr class="noCover"><td class="line"><a name="91">91</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="92">92</a></td><td class="hits"></td><td class="code">        Args:</td></tr><tr class="noCover"><td class="line"><a name="93">93</a></td><td class="hits"></td><td class="code">            delim (str, optional): CSV delimiter to be used. Defaults to &#39;,&#39;.</td></tr><tr class="noCover"><td class="line"><a name="94">94</a></td><td class="hits"></td><td class="code">            override_header (Iterable[str], optional): Enables overriding the default CSV header (labels only, cannot be used to &#39;select columns&#39;). (Must be same length as this report&#39;s default &#96;table_header&#96;).</td></tr><tr class="noCover"><td class="line"><a name="95">95</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="96">96</a></td><td class="hits"></td><td class="code">        Raises:</td></tr><tr class="noCover"><td class="line"><a name="97">97</a></td><td class="hits"></td><td class="code">            ValueError: If override_header is invalid.</td></tr><tr class="noCover"><td class="line"><a name="98">98</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="99">99</a></td><td class="hits"></td><td class="code">        Returns:</td></tr><tr class="noCover"><td class="line"><a name="100">100</a></td><td class="hits"></td><td class="code">            str: This report, in CSV format.</td></tr><tr class="noCover"><td class="line"><a name="101">101</a></td><td class="hits"></td><td class="code">        &#34;&#34;&#34;        </td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="102">102</a></td><td class="hits">1</td><td class="code">        header &#61; self.table_header()</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="103">103</a></td><td class="hits">1</td><td class="code">        if override_header:</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="104">104</a></td><td class="hits">1</td><td class="code">            if len(override_header) !&#61; len(header):</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="105">105</a></td><td class="hits">1</td><td class="code">                raise ValueError(f&#39;&#39;&#39;override_header must be length {len(header)}, to align with table_header: {header}. override_header length: {len(override_header)}. override_header: {override_header})&#39;&#39;&#39;)</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="106">106</a></td><td class="hits">1</td><td class="code">            header &#61; override_header</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="107">107</a></td><td class="hits">1</td><td class="code">        return as_csv(self._as_tuples(), header, delim)</td></tr><tr class="noCover"><td class="line"><a name="108">108</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="109">109</a></td><td class="hits">1</td><td class="code">    def save_as_file(self, filename: str, output_directory: str &#61; &#39;./&#39;, **kwargs) -&gt; int:</td></tr><tr class="noCover"><td class="line"><a name="110">110</a></td><td class="hits"></td><td class="code">        &#34;&#34;&#34;Save this CSVReport to a file.</td></tr><tr class="noCover"><td class="line"><a name="111">111</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="112">112</a></td><td class="hits"></td><td class="code">        Args:</td></tr><tr class="noCover"><td class="line"><a name="113">113</a></td><td class="hits"></td><td class="code">            output_directory (str): The path where the CSV will be saved.</td></tr><tr class="noCover"><td class="line"><a name="114">114</a></td><td class="hits"></td><td class="code">            filename (str): Will be used as the file name.</td></tr><tr class="noCover"><td class="line"><a name="115">115</a></td><td class="hits"></td><td class="code">            kwargs: Additional arguments are passed to &#96;as_csv()&#96; (e.g. override_header)</td></tr><tr class="noCover"><td class="line"><a name="116">116</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="117">117</a></td><td class="hits"></td><td class="code">        Returns:</td></tr><tr class="noCover"><td class="line"><a name="118">118</a></td><td class="hits"></td><td class="code">            int: Amount of bytes written to the file. (See &#96;TextIOBase.write()&#96;)</td></tr><tr class="noCover"><td class="line"><a name="119">119</a></td><td class="hits"></td><td class="code">        &#34;&#34;&#34;</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="120">120</a></td><td class="hits">1</td><td class="code">        io.ensure_directory_exist(output_directory)</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="121">121</a></td><td class="hits">1</td><td class="code">        filename &#61; _sanitize_csv_filename(filename)</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="122">122</a></td><td class="hits">1</td><td class="code">        out_file_path &#61; os.path.join(output_directory, filename)</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="123">123</a></td><td class="hits">1</td><td class="code">        with open(out_file_path, &#39;w&#39;) as out_file:</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="124">124</a></td><td class="hits">1</td><td class="code">            return out_file.write(self.as_csv(**kwargs))</td></tr><tr class="noCover"><td class="line"><a name="125">125</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="126">126</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="127">127</a></td><td class="hits">1</td><td class="code">def as_csv(data: Iterable[Tuple], header: Iterable[str] &#61; None, delim&#61;&#39;,&#39;) -&gt; str:</td></tr><tr class="noCover"><td class="line"><a name="128">128</a></td><td class="hits"></td><td class="code">    &#34;&#34;&#34;Convert a list of tuples into a CSV table.</td></tr><tr class="noCover"><td class="line"><a name="129">129</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="130">130</a></td><td class="hits"></td><td class="code">    Args:</td></tr><tr class="noCover"><td class="line"><a name="131">131</a></td><td class="hits"></td><td class="code">        data (Iterable[Tuple]): The data tuples. Each tuple should be the same size, and the same size as the header.</td></tr><tr class="noCover"><td class="line"><a name="132">132</a></td><td class="hits"></td><td class="code">        header (Iterable[str]): Header for the CSV table. Optional.</td></tr><tr class="noCover"><td class="line"><a name="133">133</a></td><td class="hits"></td><td class="code">        delim (str, optional): CSV delimiter. Defaults to &#39;,&#39;.</td></tr><tr class="noCover"><td class="line"><a name="134">134</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="135">135</a></td><td class="hits"></td><td class="code">    Returns:</td></tr><tr class="noCover"><td class="line"><a name="136">136</a></td><td class="hits"></td><td class="code">        str: The data, represented as a CSV.</td></tr><tr class="noCover"><td class="line"><a name="137">137</a></td><td class="hits"></td><td class="code">    &#34;&#34;&#34;</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="138">138</a></td><td class="hits">1</td><td class="code">    csv_lines &#61; []</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="139">139</a></td><td class="hits">1</td><td class="code">    if header:</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="140">140</a></td><td class="hits">1</td><td class="code">        csv_lines.append(delim.join(header))</td></tr><tr class="noCover"><td class="line"><a name="141">141</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="142">142</a></td><td class="hits">1</td><td class="code">    def sanitize(datum):</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="143">143</a></td><td class="hits">1</td><td class="code">        return f&#39;&#34;{datum}&#34;&#39; if delim in str(datum) else str(datum)</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="144">144</a></td><td class="hits">1</td><td class="code">    for line_data in data:</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="145">145</a></td><td class="hits">1</td><td class="code">        line_data &#61; list(map(sanitize, line_data))</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="146">146</a></td><td class="hits">1</td><td class="code">        csv_lines.append(delim.join(line_data))</td></tr><tr class="noCover"><td class="line"><a name="147">147</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="148">148</a></td><td class="hits">1</td><td class="code">    return &#39;\n&#39;.join(csv_lines)</td></tr><tr class="noCover"><td class="line"><a name="149">149</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="150">150</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="151">151</a></td><td class="hits">1</td><td class="code">def _sanitize_csv_filename(filename: str) -&gt; str:</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="152">152</a></td><td class="hits">1</td><td class="code">    if not filename.endswith(&#39;.csv&#39;):</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="153">153</a></td><td class="hits">1</td><td class="code">        filename &#61; f&#39;{filename}.csv&#39;</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="154">154</a></td><td class="hits">1</td><td class="code">    return pathvalidate.sanitize_filename(filename)</td></tr>